@@ -1,6 +1,7 @@
 from gym.envs.registration import register
 
+
 register(
-    id='jss-v1',
-    entry_point='JSSEnv.envs:JssEnv',
-)
\ No newline at end of file
+    id="jss-v1",
+    entry_point="JSSEnv.envs:JssEnv",
+)
